@@ -3,19 +3,18 @@
 # Copyright (C) 2012 Jay Sigbrandt <jsigbrandt@slb.com>
 #                    Martin Owens <doctormo@gmail.com>
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3 of the License, or
-# (at your option) any later version.
+# This library is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 3.0 of the License, or (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
+# This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# You should have received a copy of the GNU Lesser General Public
+# License along with this library.
 #
 """
 Test crontab usage.
@@ -106,6 +105,28 @@ class UseTestCase(unittest.TestCase):
         item.command = str('nothing')
         self.assertEqual(item.render(), '* * * * * nothing')
 
+    def test_09_slice_validation(self):
+        """CronSlices class and objects can validate"""
+        CronSlices = crontab.CronSlices
+        self.assertTrue(CronSlices('* * * * *').is_valid())
+        self.assertTrue(CronSlices.is_valid('* * * * *'))
+        self.assertTrue(CronSlices.is_valid('*/2 * * * *'))
+        self.assertTrue(CronSlices.is_valid('* 1,2 * * *'))
+        self.assertTrue(CronSlices.is_valid('* * 1-5 * *'))
+        self.assertTrue(CronSlices.is_valid('* * * * MON-WED'))
+        self.assertTrue(CronSlices.is_valid('@reboot'))
+
+        sliced = CronSlices('* * * * *')
+        sliced[0].parts = [300]
+        self.assertEqual(str(sliced), '300 * * * *')
+        self.assertFalse(sliced.is_valid())
+        self.assertFalse(CronSlices.is_valid('P'))
+        self.assertFalse(CronSlices.is_valid('*/61 * * * *'))
+        self.assertFalse(CronSlices.is_valid('* 1,300 * * *'))
+        self.assertFalse(CronSlices.is_valid('* * 50-1 * *'))
+        self.assertFalse(CronSlices.is_valid('* * * * FRO-TOO'))
+        self.assertFalse(CronSlices.is_valid('@retool'))
+
     def tearDown(self):
         for filename in self.filenames:
             if os.path.exists(filename):
